-- maze generating script
-- Note: on map, '0' = path and '1' = wall

local gen = require("maze")

local gr = love.graphics

function love.load()
	cells = { 20, 15 }	-- number of cells
	size  = { 15, 15 }	-- cell size (for screen display)
	map = gen( cells[1], cells[2] )
	show_text = false
	show_maze = true
	save_maze = false
	end

function love.update(dt)
	map = gen( cells[1], cells[2] )
	if save_maze then save( map ) end
	end

function love.draw()
	gr.setColor( 0, 55, 0, 255 )	-- backdrop behing maze
	gr.rectangle( 'fill', 0, 0, size[1]*cells[1], size[2]*cells[2] )
	for j = 1, #map do
		for i = 1, #map[j] do
			if show_text then		-- show cell values
				gr.setColor( 255, 0, 0, 255 )
				gr.print( map[j][i], size[1]*(i-1)+4, size[2]*(j-1)+4 )
				end
			if show_maze then		-- draw actual maze
				gr.setColor( 255, 255, 255, 155 )
				if map[j][i] == 0 then gr.rectangle('fill',size[1]*(i-1),size[2]*(j-1),size[1],size[2]) end
				end
			end
		end
	gr.setCaption( 'fps: '..love.timer.getFPS()..' cells: ('..cells[1]..' by '..cells[2]..')' )
	end

function love.keypressed( key )
	if key == 'escape'	then love.event.quit() end
	if key == 't' 		then show_text = not show_text end
	if key == 'm'		then show_maze = not show_maze end
	if key == 'f5'		then save_maze = true end
	if key == 'down'	or key == 's'	then cells[2] = cells[2] + 1 end
	if key == 'up'		or key == 'w'	then cells[2] = cells[2] - 1 end
	if key == 'left'	or key == 'a'	then cells[1] = cells[1] - 1 end
	if key == 'right'	or key == 'd'	then cells[1] = cells[1] + 1 end
	end

function save( m )
	-- for Windows, saved to C:\Users\Guy\AppData\Roaming\LOVE\maze
	file = love.filesystem.newFile( 'map'..cells[1]..'x'..cells[2]..'.txt' )
	file:open( 'w' )
	for j = 1, #m do
		local str = ''
		for i = 1, #m[j] do
			str = str .. m[j][i]
			end
		str = str.. '\r\n'
		file:write( str )
		end
	file:close()
	save_maze = false
	end
